@@ -560,3 +560,58 @@ class Version(models.Model):
                 versions.append(v)
         versions.sort(lambda a, b: cmp(b.saved_at, a.saved_at))
         return versions
+
+
+class TestBlock(models.Model):
+    """ this is a pageblock that is exclusively for pagetree's
+    internal tests so we have some kind of block to test with
+    without having to pull in the whole django-pageblocks
+    package and its dependencies.
+
+    You should never use it. In fact, forget that you ever saw this.
+    """
+    pageblocks = generic.GenericRelation(PageBlock)
+    body = models.TextField(blank=True)
+
+    template_file = "pagetree/testblock.html"
+    display_name = "Test Block"
+
+    def __unicode__(self):
+        return unicode(self.pageblock())
+
+    def pageblock(self):
+        return self.pageblocks.all()[0]
+
+    @classmethod
+    def add_form(self):
+        class AddForm(forms.Form):
+            body = forms.CharField(
+                widget=forms.widgets.Textarea(attrs={'cols': 80}))
+        return AddForm()
+
+    @classmethod
+    def create(self, request):
+        return TestBlock.objects.create(body=request.POST.get('body', ''))
+
+    @classmethod
+    def create_from_dict(self, d):
+        return TestBlock.objects.create(body=d.get('body', ''))
+
+    def edit_form(self):
+        class EditForm(forms.Form):
+            body = forms.CharField(widget=forms.widgets.Textarea(),
+                                   initial=self.body)
+        return EditForm()
+
+    def edit(self, vals, files):
+        self.body = vals.get('body', '')
+        self.save()
+
+    def as_dict(self):
+        return dict(body=self.body)
+
+    def summary_render(self):
+        if len(self.body) < 61:
+            return self.body
+        else:
+            return self.body[:61] + "..."
